/*
 * Daneel - Dalvik to Java bytecode compiler
 * Copyright (C) 2011  IcedRobot team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is subject to the "Classpath" exception:
 *
 * Linking this library statically or dynamically with other modules is
 * making a combined work based on this library.  Thus, the terms and
 * conditions of the GNU General Public License cover the whole
 * combination.
 *
 * As a special exception, the copyright holders of this library give you
 * permission to link this library with independent modules to produce an
 * executable, regardless of the license terms of these independent
 * modules, and to copy and distribute the resulting executable under terms
 * of your choice, provided that you also meet, for each linked independent
 * module, the terms and conditions of the license of that module.  An
 * independent module is a module which is not derived from or based on
 * this library.  If you modify this library, you may extend this exception
 * to your version of the library, but you are not obligated to do so.  If
 * you do not wish to do so, delete this exception statement from your
 * version.
 */

package org.icedrobot.daneel.rewriter;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertSame;

import java.lang.reflect.Field;

import org.icedrobot.daneel.DexifyingRunner;
import org.junit.Test;
import org.junit.runner.RunWith;

@RunWith(DexifyingRunner.class)
public class FieldConstantTest {

    @Test
    public void testConstLong() throws Exception {
        Field f = DEXCode.class.getField("CONST_LONG");
        assertSame(long.class, f.getType());
        assertEquals(Long.MAX_VALUE, f.getLong(null));
    }

    @Test
    public void testConstFloat1() throws Exception {
        Field f = DEXCode.class.getField("CONST_FLOAT1");
        assertSame(float.class, f.getType());
        assertEquals(0.5f, f.getFloat(null), 0);
    }

    @Test
    public void testConstFloat2() throws Exception {
        Field f = DEXCode.class.getField("CONST_FLOAT2");
        assertSame(float.class, f.getType());
        assertEquals(0.23f, f.getFloat(null), 0);
    }

    @Test
    public void testConstDouble() throws Exception {
        Field f = DEXCode.class.getField("CONST_DOUBLE");
        assertSame(double.class, f.getType());
        assertEquals(0.42, f.getDouble(null), 0);
    }

    // Keep this class named "DEXCode" to push it through Daneel.
    public static class DEXCode {
        public static final long CONST_LONG = Long.MAX_VALUE;
        public static final float CONST_FLOAT1 = 0.5f;
        public static final float CONST_FLOAT2 = 0.23f;
        public static final double CONST_DOUBLE = 0.42;
    };
}
